PrimitiveValues

Trait PrimitiveValues 

pub trait PrimitiveValues {
    type T;

    // Required method
    fn to_primitive_values(&self) -> Self::T;
}
Used to convert a type to primitive values representing it.

Required Associated Types

type T

A tuple of types, to represent the current value.

Required Methods

fn to_primitive_values(&self) -> Self::T

Convert a value to primitive types representing it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PrimitiveValues for Ipv4Addr

Source

type T = (u8, u8, u8, u8)

Source

fn to_primitive_values(&self) -> (u8, u8, u8, u8)

Source

impl PrimitiveValues for Ipv6Addr

Implementors